@@ -2,6 +2,7 @@ from einops.layers.torch import Rearrange as _Rearrange
 
 from .func import reduce_dict_by, summarize_dict_by, generate_inf_seq, compose, listdir, with_printed, \
     with_printed_shape, is_bad_num, ifelse, dict_add, count_parameters, as_list
+from .func import tensorneko_path as get_tensorneko_path
 from .type import ModuleFactory, Shape, Device
 from .configuration import Configuration
 from .string_getter import get_activation, get_loss
@@ -14,6 +15,7 @@ Rearrange = _Rearrange
 _ = shortcut
 F = func.F
 
+tensorneko_path = get_tensorneko_path()
 
 __all__ = [
     "reduce_dict_by",
@@ -37,5 +39,6 @@ __all__ = [
     "__",
     "Rearrange",
     "_",
-    "F"
-]
\ No newline at end of file
+    "F",
+    "tensorneko_path"
+]
