@@ -1,7 +1,9 @@
 from .imshow import imshow
 from .log_graph import log_graph
+from . import web
 
 __all__ = [
     "imshow",
-    "log_graph"
-]
\ No newline at end of file
+    "log_graph",
+    "web"
+]
